@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 use Rope;
 use Rope::Autoload;
@@ -166,7 +166,7 @@ function print_line => sub {
 		: $self->align eq 'right'
 		? $self->max_width - $line_width
 		: $self->pad;
-	$pad = $pad ? " " x $pad : ""; 
+	$pad = $pad && $pad > 0 ? " " x $pad : ""; 
 	my $fh = $self->fh;
 	for (@{$line}) {
 		next unless scalar @{$_};
@@ -198,7 +198,7 @@ Ascii::Text - module for generating ASCII text in various fonts and styles
 
 =head1 VERSION
 
-Version 0.10
+Version 0.11
 
 =cut
 
