@@ -4,8 +4,7 @@ use Rope::Cmd;
 use Types::Standard qw/Str Int Bool Enum/;
 use Ascii::Text;
 
-my $title = Ascii::Text->new( font => 'Boomer', align => 'center', color => 'green')->stringify('Ascii Text', 1);
-title $title;
+title(Ascii::Text->new( font => 'Boomer', align => 'center', color => 'green')->stringify('Ascii Text', 1));
 
 abstract 'script for generating ASCII text in various fonts and styles';
  
